<?php # $Id: serendipity_lang_hu.inc.php 93 2005-05-12 10:49:41Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Mrton Psz <ful_s@AT@passwd.hu> and Hrotk Gbor <roti@al.pmmf.hu>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-2');
@define('SQL_CHARSET', 'latin2');
@define('DATE_LOCALES', 'hu_HU.ISO-8859-2, hu_HU.ISO8859-2, hungarian, hu, hu_HU');
@define('DATE_FORMAT_ENTRY', '%Y. %B %e. (%A) ');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Adminisztrcis Kszlet');
@define('HAVE_TO_BE_LOGGED_ON', 'Az oldal megtekintshez elbb be kell jelentkezned');
@define('WRONG_USERNAME_OR_PASSWORD', 'gy tnik, hogy hibs felhasznl-nevet vagy jelszt adtl meg');
@define('APPEARANCE', 'Kinzet');
@define('MANAGE_STYLES', 'Stlusok kezelse');
@define('CONFIGURE_PLUGINS', 'Bepl modulok belltsa');
@define('CONFIGURATION', 'Belltsok');
@define('BACK_TO_BLOG', 'Vissza a Weblog-hoz');
@define('LOGIN', 'Belps');
@define('LOGOUT', 'Kilps');
@define('LOGGEDOUT', 'Kilpett.');
@define('CREATE', 'Ltrehozs');
@define('SAVE', 'Ments');
@define('NAME', 'Nv');
@define('CREATE_NEW_CAT', 'j Kategria Ltrehozsa');
@define('I_WANT_THUMB', 'Kis elnzeti kpeket szeretnk a bejegyzsben hasznlni.');
@define('I_WANT_BIG_IMAGE', 'Nagyobb kpeket szeretnk a bejegyzsben hasznlni.');
@define('I_WANT_NO_LINK', 'Kpknt szeretnm megjelenteni');
@define('I_WANT_IT_TO_LINK', 'Az albbi hivatkozsknt szeretnm megjelenteni:');
@define('BACK', 'Vissza');
@define('FORWARD', 'Elre');
@define('ANONYMOUS', 'Ismeretlen');
@define('NEW_TRACKBACK_TO', 'j visszahivatkozs kszlt ehhez:');
@define('NEW_COMMENT_TO', 'Az albbi bejegyzshez j hozzszls rkezett:');
@define('RECENT', 'Friss...');
@define('OLDER', 'Rgebbi...');
@define('DONE', 'Ksz');
@define('WELCOME_BACK', 'dv ismt,');
@define('TITLE', 'Cm');
@define('DESCRIPTION', 'Lers');
@define('PLACEMENT', 'Elhelyezs');
@define('DELETE', 'Trl');
@define('SAVE', 'Ment');
@define('UP', 'FEL');
@define('DOWN', 'LE');
@define('ENTRIES', 'bejegyzsek');
@define('NEW_ENTRY', 'j bejegyzs');
@define('EDIT_ENTRIES', 'Szerkeszts');
@define('CATEGORIES', 'Kategrik');
@define('WARNING_THIS_BLAHBLAH', "FIGYELEM:\\nEz sokig eltarthat, ha csak kevs kpnek van elnzeti kpe.");
@define('CREATE_THUMBS', 'Elnzeti kpek jragenerlsa');
@define('MANAGE_IMAGES', 'Kpek kezelse');
@define('NAME', 'Nv');
@define('EMAIL', 'email');
@define('HOMEPAGE', 'Honlap');
@define('COMMENT', 'Megjegyzs');
@define('REMEMBER_INFO', 'Megjegyezzem a megadott adatokat? ');
@define('SUBMIT_COMMENT', 'Hozzszls bekldse');
@define('NO_ENTRIES_TO_PRINT', 'Nincs mit megjelenteni');
@define('COMMENTS', 'Hozzszlsok');
@define('ADD_COMMENT', 'Hozzszls hozzfzse');
@define('NO_COMMENTS', 'Nincs hozzszls');
@define('POSTED_BY', 'Bekldte');
@define('ON', ' az albbi idpontban ');
@define('A_NEW_COMMENT_BLAHBLAH', 'j hozzszls rkezett a "%s" blog-ban ehhez a bejegyzshez: "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'j hivatkozs trtnt msik oldalrl erre a blog bejegyzsre: "%s".');
@define('NO_CATEGORY', 'Nincsenek kategrik');
@define('ENTRY_BODY', 'A bejegyzs trzse');
@define('EXTENDED_BODY', 'Rszletesebb trzs');
@define('CATEGORY', 'Kategria');
@define('EDIT', 'Szerkeszts');
@define('NO_ENTRIES_BLAHBLAH', 'Nem talltam semmit (%s)' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'A keressre (%s) %s tallat rkezett:');
@define('IMAGE', 'Kp');
@define('ERROR_FILE_NOT_EXISTS', 'Hiba: a rgi fjlnv nem ltezik!');
@define('ERROR_FILE_EXISTS', 'Hiba: az j fjlnv mr ltezik, vlassz msikat!');
@define('ERROR_SOMETHING', 'Hiba: valami nem stimmel.');
@define('ADDING_IMAGE', 'Kp hozzadsa...');
@define('THUMB_CREATED_DONE', 'Elnzeti kp ltrehozva.<br/>Ksz.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Hiba: A fjl mr ltezik a gpeden!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ismeretlen hiba trtnt, a fjl nincs feltltve. Taln a fjl mrete nagyobb mint a szerveren belltott megengedett maximum rtk. Ezt a belltst a szerver zemeltetje tudja megvltoztatni.');
@define('GO', 'OK');
@define('NEWSIZE', 'j mret: ');
@define('RESIZE_BLAHBLAH', '<b>tmretezs %s</b>');
@define('ORIGINAL_SIZE', 'Eredeti mret: <i>%sx%s</i> kppont');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Itt mdosthatja a kp mrett. Ha arnyosan szeretn a kpet tmretezni, elg az egyik dobozban mdostani a szmot,majd megnyomni a TAB billentyt -- az j mret automatikusan kerl meghatrozsra, gy a kp nem lesz arnytalan</p>');
@define('QUICKJUMP_CALENDAR', 'Gyors naptrra ugrs');
@define('QUICKSEARCH', 'Gyorskeress');
@define('SEARCH_FOR_ENTRY', 'Bejegyzs keresse');
@define('ARCHIVES', 'Archvum');
@define('BROWSE_ARCHIVES', 'Havi archvum tallzsa');
@define('TOP_REFERRER', 'Legtbbet ide hivatkozk');
@define('SHOWS_TOP_SITES', 'Honlapok, melyek a blog-odra linkeltek');
@define('TOP_EXITS', 'Kilpsek toplistja');
@define('SHOWS_TOP_EXIT', 'A blog elhagysa utni leggyakoribb hivatkozsokat mutatja');
@define('SYNDICATION', 'Integrci - Egyesls');
@define('SHOWS_RSS_BLAHBLAH', 'Az RSS feliratkozs linkek mutatsa');
@define('ADVERTISES_BLAHBLAH', 'Reklmozza a blog-od eredett');
@define('HTML_NUGGET', 'HTML-tredk');
@define('HOLDS_A_BLAHBLAH', 'Elhelyez egy HTML-tredket a margra');
@define('TITLE_FOR_NUGGET', 'A tredk cme');
@define('THE_NUGGET', 'A HTML-tredk!');
@define('SYNDICATE_THIS_BLOG', 'Feliratkozs erre a blog-ra');
@define('YOU_CHOSE', 'Ezt vlasztottad: %s');
@define('IMAGE_ROTATE_LEFT', 'A kp 90 fokos elforgatsa az ramutat jrsval ellenttes irnyba');
@define('IMAGE_ROTATE_RIGHT', 'A kp 90 fokos elforgatsa az ramutat jrsval megegyez irnyba');
@define('IMAGE_SIZE', 'Kpmret');
@define('IMAGE_AS_A_LINK', 'Kp beszrsa');
@define('POWERED_BY', 'Powered by');
@define('TRACKBACKS', 'Visszahivatkozsok');
@define('TRACKBACK', 'Visszahivatkozs');
@define('NO_TRACKBACKS', 'Nincsenek visszahivatkozsok');
@define('TOPICS_OF', 'Cmek innen: ');
@define('VIEW_FULL', 'Minden megtekintse');
@define('VIEW_TOPICS', 'Cmek megtekintse');
@define('AT', ' ekkor: ');
@define('SET_AS_TEMPLATE', 'Sablonnak kivlaszt');
@define('IN', ' ebben: ');
@define('EXCERPT', 'Kivonat');
@define('TRACKED', 'Nyomon-kvetett');
@define('LINK_TO_ENTRY', 'Link a bejegyzshez');
@define('LINK_TO_REMOTE_ENTRY', 'Link a tvoli bejegyzshez');
@define('IP_ADDRESS', 'IP cm');
@define('USER', 'Felhasznl');
@define('THUMBNAIL_USING_OWN', 'Sajt magt (%s) hasznlom elnzeti kpnek, mert elg kicsi az eredeti kp.');
@define('THUMBNAIL_FAILED_COPY', 'Sajt magt (%s) szerettem volna elnzeti kpnek hasznlni, de nem sikerlt odamsolni!');
@define('AUTHOR', 'Szerz');
@define('LAST_UPDATED', 'Utols Frissts');
@define('TRACKBACK_SPECIFIC', 'Visszahivatkozs specifikus URI ehhez a bejegyzshez');
@define('DIRECT_LINK', 'Kzvetlen link ehhez a bejegyzshez.');
@define('COMMENT_ADDED', 'A hozzszlsodat sikeresen rgztettem. ');
@define('COMMENT_ADDED_CLICK', 'Kattints %side a visszatrshez%s, vagy %side az ablak bezrshoz%s.');
@define('COMMENT_NOT_ADDED_CLICK', 'Kattints %side%s a hozzszlsokhoz, vagy %side%s ezen ablak bezrshoz.');
@define('COMMENTS_DISABLE', 'Ne lehessen hozzszlni');
@define('COMMENTS_ENABLE', 'Lehessen hozzszlni');
@define('COMMENTS_CLOSED', 'A szerz letiltotta a hozzszlst.');
@define('EMPTY_COMMENT', 'Nem tlttted ki a hozzszls rovatot, %sprbld meg%s jra');
@define('ENTRIES_FOR', 'Bejegyzsek innen: %s');
@define('DOCUMENT_NOT_FOUND', 'A %s dokumentumot nem tallom.');
@define('USERNAME', 'Felhasznli nv');
@define('PASSWORD', 'Jelsz');
@define('AUTOMATIC_LOGIN', 'Adatok megjegyzse');
@define('SERENDIPITY_INSTALLATION', 'Serendipity Telepts');
@define('LEFT', 'bal');
@define('RIGHT', 'jobb');
@define('HIDDEN', 'rejtett');
@define('REMOVE_TICKED_PLUGINS', 'A bejellt bepl modulok eltvoltsa');
@define('SAVE_CHANGES_TO_LAYOUT', 'Vltozsok mentse az oldal szerkezetbe (layout)');
@define('COMMENTS_FROM', 'Hozzszlsok innen');
@define('ERROR', 'Hiba');
@define('ENTRY_SAVED', 'A bejegyzs mentve');
@define('DELETE_SURE', 'Biztos, hogy vglegesen kitrld a #%s-t?');
@define('NOT_REALLY', 'Nem');
@define('DUMP_IT', 'Igen');
@define('RIP_ENTRY', 'Bejegyzs (#%s) trlve.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategria (#%s) trlve. A korbbi cikkeket ide soroltam: #%s.');
@define('CATEGORY_DELETED', 'A #%s kategria trlve.');
@define('INVALID_CATEGORY', 'Nem adtl meg trlend kategrit');
@define('CATEGORY_SAVED', 'A kategrit elmentettem');
@define('SELECT_TEMPLATE', 'Vlaszd ki a sablont, amit a blog-odhoz hasznlni szeretnl');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'A bejegyzseket nem sikerlt beilleszteni!');
@define('MT_DATA_FILE', 'Mozgathat tpus adatfjl');
@define('FORCE', 'Knyszert (force)');
@define('CREATE_AUTHOR', 'Szerz ltrehozsa \'%s\'.');
@define('CREATE_CATEGORY', 'Kategria ltrehozsa \'%s\'.');
@define('MYSQL_REQUIRED', 'Ezen mvelet vgrehajtshoz szksg van a MySQL kiterjesztsre.');
@define('COULDNT_CONNECT', 'Nem tudok kapcsoldni az albbi MySQL adatbzishoz: %s.');
@define('COULDNT_SELECT_DB', 'Nem sikerlt a SELECT: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Nem tallom a felhasznli informcikat: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Nem tallom a kategria informcikat: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Nem tallom a bejegyzs informcikat: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Nem tallom a hozzszls informcikat: %s.');
@define('YES', 'Igen');
@define('NO', 'Nem');
@define('USE_DEFAULT', 'Alaprtelmezett');
@define('CHECK_N_SAVE', 'Ellenrzs &amp; ments');
@define('DIRECTORY_WRITE_ERROR', 'A %s szt nem tudom felvenni a sztrba. Krlek ellenrizd a hozzfrsi jogokat.');
@define('DIRECTORY_CREATE_ERROR', 'A %s knyvtr nem ltezik, s nem is tudom ltrehozni. Krlek hozd ltre Te');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; fut <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Nem tudom futtatni a %s binrist');
@define('FILE_WRITE_ERROR', 'Nem tudom rni a %s fjlt.');
@define('FILE_CREATE_YOURSELF', 'Krlek hozd ltre a fjlt, vagy ellenrizd a hozzfrsi jogokat');
@define('COPY_CODE_BELOW', '<br />* Msold a lenti kdot a %s fjlba (knyvtr: %s):<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'A www-t cserld ki arra a felhasznlra, aki az apache-ot futtatja (pl. nobody).');
@define('BROWSER_RELOAD', 'Ha ksz vagy, kattints a bngsz "Frissts" gombjra.');
@define('DIAGNOSTIC_ERROR', 'Talltam valami hibt az ltalad megadott adatokban:');
@define('SERENDIPITY_NOT_INSTALLED', 'A Serendipity mg nincs teleptve. Kattints <a href="%s">ide</a> a teleptshez.');
@define('INCLUDE_ERROR', 'serendipity hiba: nem megy az "include %s" - kilpek.');
@define('DATABASE_ERROR', 'serendipity hiba: nem tudok kapcsoldni az adatbzishoz - kilpek.');
@define('CREATE_DATABASE', 'Ltrehozom az alaprtelmezett adatbzis tblkat...');
@define('ATTEMPT_WRITE_FILE', 'Megksrlek rni a %s fjlba...');
@define('WRITTEN_N_SAVED', 'A belltsok mentse sikeres');
@define('IMAGE_ALIGNMENT', 'Kp elrendezs/elhelyezs');
@define('ENTER_NEW_NAME', 'Az albbi fjl j neve: ');
@define('RESIZING', 'tmretezs');
@define('RESIZE_DONE', 'Ksz (%s kp tmretezve).');
@define('SYNCING', 'Szinkronizlom az adatbzist a kpek knyvtrval.');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Ksz (%s kpet szinkronizltam).');
@define('FILE_NOT_FOUND', 'Nem tallom a <b>%s</b> fjlt, lehet, hogy mr trlve lett?');
@define('ABORT_NOW', 'Azonnali megszakts');
@define('REMOTE_FILE_NOT_FOUND', 'Nem talltam ilyen fjlt a tvoli szerveren, biztos, hogy a: <b>%s</b> URL helyes?');
@define('FILE_FETCHED', '%s leszedve, mint %s');
@define('FILE_UPLOADED', 'A %s fjlt sikeresen feltltettem %s nven');
@define('WORD_OR', 'Vagy');
@define('SCALING_IMAGE', 'tmretezem %s-t %s x %s kppontra');
@define('KEEP_PROPORTIONS', 'Arnyok megrzse');
@define('REALLY_SCALE_IMAGE', 'Biztos, hogy tmretezed? Nem lehet visszafordtani a folyamatot!');
@define('TOGGLE_ALL', 'Minden kibontsa');
@define('TOGGLE_OPTION', 'Belltsok');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Feliratkozom erre a bejegyzsre');
@define('UNSUBSCRIBE_OK', "%s leiratkozott errl a bejegyzsrl");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'j hozzszls rkezett az albbi (feliratkozott) bejegyzshez "%s"');
@define('SUBSCRIPTION_MAIL', "Szia %s!\n\nj hozzszls rkezett a \"%s\" bejegyzshez, az albbi cmmel: \"%s\"\nAz j hozzszls szerzje: %s\n\nA bejegyzst itt tallod: %s\n\nA leiratkozshoz kattints az albbi linkre: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hello %s,\n\nj visszahivatkozs kerlt az ltalad megfigyelt bejegyzshez, a \"%s\" blog-ban, a kvetkez cm bejegyzshez \"%s\"\nA felirat neve: %s\n\nEz itt tallhat: %s\n\nA figyelst trlheted ide kattintva: %s\n");
@define('SIGNATURE', "\n-- \n%s a Serendipity motort hasznlja.\nEz a legjobb blog, te is hasznlhatod.\nItt megtudod, hogyan: <http://s9y.org>.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 inf');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 inf');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 info');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 hozzszlsok');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 inf');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', '"Fszerkeszt" mez');
@define('SYNDICATION_PLUGIN_WEBMASTER',  '"Webmester" mez');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Kp az RSS infhoz');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Kpszlessg');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Kpmagassg');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'A Webmester email cme, ha van. (res: rejtett) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'A Fszerkeszt email cme, ha van. (res: rejtett) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'A GIF/JPEG/PNG formtum kp URL-je, ha van. (res: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'kppontban, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'kppontban, max. 400');
@define('SYNDICATION_PLUGIN_TTL', '"TTL" mez (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Az az idtartam (percben), ami utn a blog-odat nem cache-elje tbb semmilyen kls honlap vagy alkalmazs (res: rejtett) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', '"Publikci Dtuma" mez');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Szerepeljen a "Publikci Dtuma" mez az RSS-csatornn annak rdekben, hogy ltszdjon a legfrissebb bejegyzs dtuma?');
@define('CONTENT', 'Tartalom');
@define('TYPE', 'Tpus');
@define('DRAFT', 'Vzlat');
@define('PUBLISH', 'Publikl');
@define('PREVIEW', 'Elnzet');
@define('DATE', 'Dtum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Vigyzat: Az ltalad megadott idpont helytelen. Hasznld az albbi formtumot: -HH-NN :PP.');
@define('CATEGORY_PLUGIN_DESC', 'Mutasd a kategrialistt.');
@define('ALL_AUTHORS', 'Az sszes szerz');
@define('CATEGORIES_TO_FETCH', 'Letltend kategrik');
@define('CATEGORIES_TO_FETCH_DESC', 'Melyik szerztl tltsk le a kategrikat?');
@define('PAGE_BROWSE_ENTRIES', '%s oldal ennyibl: %s, sszes bejegyzs: %s');
@define('PREVIOUS_PAGE', 'elz oldal');
@define('NEXT_PAGE', 'kvetkez oldal');
@define('ALL_CATEGORIES', 'Minden kategria');
@define('DO_MARKUP', 'Forrs transzformls elvgzse.');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Dtumformzs');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Az aktulis bejegyzs dtuma, a kvetkez formtumot hasznlva: PHP strftime() vltoz. (Alaprtelmezett: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Nem tudom megnyitni a sablonfjlt, krlek frisstsd a serendipity-t!');
@define('ADVANCED_OPTIONS', 'Halad Belltsok');
@define('EDIT_ENTRY', 'Bejegyzs szerkesztse');
@define('HTACCESS_ERROR', 'A helyi webszerver ellenrzshez, rsi jogot kell adni a serendipity-nek a ".htaccess" fjlra. Ez pillanatnyilag nincs gy. Krlek az albbiak szerint mdostsd a hozzfrsi jogosultsgokat: <br />&nbsp;&nbsp;%s<br />majd tltsd jra az aktulis oldalt.');
@define('SIDEBAR_PLUGINS', 'Marg Modulok');
@define('EVENT_PLUGINS', 'Esemnyvezrl Modulok');
@define('SORT_ORDER', 'Sorrend');
@define('SORT_ORDER_NAME', 'Fjlnv');
@define('SORT_ORDER_EXTENSION', 'Kiterjeszts');
@define('SORT_ORDER_SIZE', 'Fjlmret');
@define('SORT_ORDER_WIDTH', 'Kpszlessg');
@define('SORT_ORDER_HEIGHT', 'Kpmagassg');
@define('SORT_ORDER_DATE', 'Feltlts dtuma');
@define('SORT_ORDER_ASC', 'Nvekv');
@define('SORT_ORDER_DESC', 'Cskken');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Eredeti');
@define('APPLY_MARKUP_TO', 'Jells hasznlata erre: %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'A ht els napja');
@define('SERENDIPITY_NEEDS_UPGRADE', 'A Serendipity teleptett verzija %s. gy tnik, hogy az albbi verzira szeretnl frissteni: %s, ha gy van <a href="%s">kattints ide</a> a folytatshoz.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Szia, dvzllek a Serendipity frisst-gynknl.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Az a feladatom, hogy segdkezzek a Serendipity %s frisstsben.');
@define('SERENDIPITY_UPGRADER_WHY', 'Ez az zenet azrt jelent meg, meg nemrg teleptetted a Serendipity %s, de az adatbzis migrcija mg nem trtnt meg');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Adatbzis frisstsek(%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'gy talltam, hogy az albbi .sql fjlokat le kell futtatni mieltt folytatdna a Serendipity norml futsa');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Verzifgg feladatok');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Nem talltam verzifgg feladatot');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Elvgezzem a fenti feladatokat?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nem, inkbb manulisan futtatom azokat');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Igen, mehet');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'gy ltom, nem kell a frisstst elvgezni');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity frisstsnek elksztse ksz');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'A Serendipity frisstsnek fzist figyelmen kvl hagytad, ellenrizd hogy az adatbzis megfelelen van installlva, s az idztett feladatok futnak');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'A Serendipity rendszer frisstse megtrtnt a kvetkez verzira: %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Visszatrhetsz a blog-hoz %side%s kattintva');
@define('MANAGE_USERS', 'Felhasznlk kezelse');
@define('CREATE_NEW_USER', 'j felhasznl ltrehozsa');
@define('CREATE_NOT_AUTHORIZED', 'Nem mdosthatod a veled azonos szinten lv felhasznlkat');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Nem hozhatsz ltre nlad magasabb szint felhasznlt');
@define('CREATED_USER', 'A(z) %s felhasznl ltrejtt');
@define('MODIFIED_USER', 'A %s felhasznl jellemzi megvltoztak');
@define('USER_LEVEL', 'Felhasznli szint');
@define('DELETE_USER', 'Ki akarod trlni a #%d %s felhasznlt. Jl meggondoltad? Le lesz tiltva az sszes ltala rt hozzszls a blog felletn.');
@define('DELETED_USER', 'A #%d %s felhasznl trlve.');
@define('LIMIT_TO_NUMBER', 'Hny elemet mutassunk?');
@define('ENTRIES_PER_PAGE', 'bejegyzsek oldalanknt');
@define('XML_IMAGE_TO_DISPLAY', 'XML gomb');
@define('XML_IMAGE_TO_DISPLAY_DESC','Az XML csatornkra mutat hivatkozsokat ez a kp jelli. Hagyd resen az alaprtelmezetthez, a letiltshoz rd be: \'none\'.');

@define('DIRECTORIES_AVAILABLE', 'A ltez alknyvtrak listjban, egy knyvtrra kattintva j knyvtrakat hozhatsz ltre abban a struktrban.');
@define('ALL_DIRECTORIES', 'sszes knyvtr');
@define('MANAGE_DIRECTORIES', 'Knyvtrak kezelse');
@define('DIRECTORY_CREATED', 'A kvetkez knyvtrat ltrehoztuk: <strong>%s</strong>.');
@define('PARENT_DIRECTORY', 'Szl knyvtr');
@define('CONFIRM_DELETE_DIRECTORY', 'Biztosan trld ennek a knyvtrnak minden tartalmt: %s?');
@define('ERROR_NO_DIRECTORY', 'Hiba: A knyvtr nem ltezik: %s');
@define('CHECKING_DIRECTORY', 'Fjlok ellenrzse a knyvtrban %s');
@define('DELETING_FILE', 'Fjlok trlse %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'A nem res knyvtrat nem tudom trlni. Ellenrizd a "knyszertett trls" kapcsolt ha ezeket is trlni szeretnd, majd ismteld meg a mveletet. A ltez fjlok a kvetkezk:');
@define('DIRECTORY_DELETE_FAILED', 'Ennek a knyvtrnak a trlse nem sikerlt: %s. Ellenrizd a jogosultsgokat, vagy a fenti zenetet.');
@define('DIRECTORY_DELETE_SUCCESS', 'A knyvtrt sikeresen trltk: %s.');
@define('SKIPPING_FILE_EXTENSION', 'Fjl kihagysa: hinyz kiterjeszts ennl: %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Fjl kihagysa: %s nem  olvashat.');
@define('FOUND_FILE', 'Mdostott/j fjlt talltam: %s.');
@define('ALREADY_SUBCATEGORY', 'A(z) %s mr alkategrija ennek: %s.');
@define('PARENT_CATEGORY', 'Szl kategria');
@define('IN_REPLY_TO', 'Vlasz a kvetkezre');
@define('TOP_LEVEL', 'Legfels szint');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s hrcsatorna');
@define('PERMISSIONS', 'Jogosultsgok');
@define('INTEGRITY', 'Verify Installation Integrity');
@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
@define('CHECKSUMS_PASS', 'All required files verified.');
@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
@define('SETTINGS_SAVED_AT', 'Az j belltsokat elmentettk ekkor: %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Adatbzis Belltsok');
@define('INSTALL_CAT_DB_DESC', 'Itt adhatod meg az sszes adatbzis belltst. A Serendipity-nek szksge van erre a mkdshez');
@define('INSTALL_DBTYPE', 'Adatbzis tpusa');
@define('INSTALL_DBTYPE_DESC', 'Adatbzis tpusa');
@define('INSTALL_DBHOST', 'Adatbzis hoszt');
@define('INSTALL_DBHOST_DESC', 'Az adatbzis szerver hosztneve');
@define('INSTALL_DBUSER', 'Adatbzis felhasznl');
@define('INSTALL_DBUSER_DESC', 'A felhasznli nv, amivel az adatbzisodhoz lehet kapcsoldni');
@define('INSTALL_DBPASS', 'Adatbzis jelsz');
@define('INSTALL_DBPASS_DESC', 'A fent megadott felhasznlhoz tartoz jelsz');
@define('INSTALL_DBNAME', 'Az adatbzis neve');
@define('INSTALL_DBNAME_DESC', 'Az adatbzisod neve');
@define('INSTALL_DBPREFIX', 'Az adatbzis tblk prefix-e');
@define('INSTALL_DBPREFIX_DESC', 'A tblanevek prefix-e, pl.: serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'tvonalak');
@define('INSTALL_CAT_PATHS_DESC', 'Klnfle tvonalak a fontos knyvtrakhoz s fjlokhoz. A knyvtrak vgrl ne felejtsd el a per ("\") jelet!');
@define('INSTALL_FULLPATH', 'Teljes tvonal');
@define('INSTALL_FULLPATH_DESC', 'A teljes abszolt elrsi tvonal a sajt serendipity teleptsedhez');
@define('INSTALL_UPLOADPATH', 'Feltltsi tvonal');
@define('INSTALL_UPLOADPATH_DESC', 'Minden feltlttt fjl ide kerl, relatv a  \'Full path\' bejegyzshez - ltalban \'uploads/\'');
@define('INSTALL_RELPATH', 'Relatv tvonal');
@define('INSTALL_RELPATH_DESC', 'A serendipity-hez vezet tvonal a bngszben, ltalban \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relatv "template" tvonal');
@define('INSTALL_RELTEMPLPATH_DESC', 'tvonal a "template"-eket tartalmaz knyvtrhoz - relatv a \'relative path\' bejegyzshez');
@define('INSTALL_RELUPLOADPATH', 'Relatv feltltsi tvonal');
@define('INSTALL_RELUPLOADPATH_DESC', 'A feltltsekhez vezet tvonal a bngszben - Relatv a \'relative path\' bejegyzshez');
@define('INSTALL_URL', 'URL a blog-hoz');
@define('INSTALL_URL_DESC', 'A blog-od URL-je');
@define('INSTALL_INDEXFILE', 'Index fjl');
@define('INSTALL_INDEXFILE_DESC', 'A serendipity-d index fjlja');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'ltalnos Belltsok');
@define('INSTALL_CAT_SETTINGS_DESC', 'Hatrozd meg, hogyan mkdjn a Serendipity');
@define('INSTALL_USERNAME', 'Az adminisztrtor felhasznli neve');
@define('INSTALL_USERNAME_DESC', 'A mindenhat adminisztrtor felhasznli neve');
@define('INSTALL_PASSWORD', 'Az adminisztrtor jelszava');
@define('INSTALL_PASSWORD_DESC', 'Az adminisztrtor felhasznlhoz tartoz jelsz');
@define('INSTALL_EMAIL', 'Adminisztrtori email');
@define('INSTALL_EMAIL_DESC', 'A blog adminisztrtor email cme');
@define('INSTALL_SENDMAIL', 'Kldjek levelet az adminisztrtornak?');
@define('INSTALL_SENDMAIL_DESC', 'Szeretnl levelben rteslni arrl, ha egy bejegyzsedhez valaki hozzszlst fztt?');
@define('INSTALL_SUBSCRIBE', 'Megengeded, hogy msok feliratkozzanak erre a bejegyzsre?');
@define('INSTALL_SUBSCRIBE_DESC', 'Megengeded, hogy msok feliratkozzanak erre a bejegyzsre, azaz levben rtestst kapjanak, ha valaki j hozzszlst fz hozz');
@define('INSTALL_BLOGNAME', 'Blog nv');
@define('INSTALL_BLOGNAME_DESC', 'A blog-od neve');
@define('INSTALL_BLOGDESC', 'Blog lers');
@define('INSTALL_BLOGDESC_DESC', 'A blod-od lersa');
@define('INSTALL_LANG', 'Nyelv');
@define('INSTALL_LANG_DESC', 'Milyen nyelven szljon a blod-od?');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Megjelentsi belltsok');
@define('INSTALL_CAT_DISPLAY_DESC', 'A serendipity kinzetnek belltsai');
@define('INSTALL_WYSIWYG', 'A WYSIWYG szerkeszt hasznlata');
@define('INSTALL_WYSIWYG_DESC', 'Szeretnd hasznlni a WYSIWYG szerkesztt? (IE5+ alatt mkdik, valamint rszben a Mozilla 1.3+ alkalmazsban)');
@define('INSTALL_XHTML11', 'Knyszertett XHTML 1.1 megfelelsg');
@define('INSTALL_XHTML11_DESC', 'Az oldalak mindenkpp megfeleljenek XHTML 1.1 szabvnynak (problmt okozhat a rgebbi 4-edik genercis bngszk esetben)');
@define('INSTALL_POPUP', 'Engedlyezed a felbukkan (popup) ablakok hasznlatt');
@define('INSTALL_POPUP_DESC', 'Szeretnd, hogy a hozzszlsok, visszahivatkozsok esetben legyenek felbukkan ablakok?');
@define('INSTALL_EMBED', 'A serendipity begyazott alkalmazsknt fut?');
@define('INSTALL_EMBED_DESC', 'Amennyiben szeretnd a serendipity-t egy szokvnyos oldalba gyazni, vlaszd ezt az opcit, s gy csak a tartalom jelenik meg fejlc nlkl. Hasznt veheted az "indexFile" opcinak, hogy hasznlni tudj egy "wrapper class"-t, ahov a honlapod eredeti fejlct. Tovbbi informcirt lsd a README fjlt!');
@define('INSTALL_TOP_AS_LINKS', 'A "Top Exits/Ide hivatkozk"-eket linkknt jelentsem meg?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"nem": Az "Kilpk" s a "Hivatkozk" sima szvegknt jelennek meg elkerlve a "google spam"-et. "igen": Az "kilpk" s a "Hivatkozk" linkknt jelennek meg. "alaprtelmezett": A globlis belltst hasznlja (javasolt).');
@define('INSTALL_BLOCKREF', 'Tiltott ide hivatkozk');
@define('INSTALL_BLOCKREF_DESC', 'Van olyan gp, amelyet nem szeretne megjelenteni az ide hivatkozk listjban? Vlassza el ezeket a cmeket \';\'-vel. A cmek akkor is blokkoldnak, ha a szveg kzepn van egyezs!');
@define('INSTALL_REWRITE', 'URL trs');
@define('INSTALL_REWRITE_DESC', 'Vlaszd ki a szablyokat, amelyeket az URL generls sorn hasznlni szeretnl. Az tr szablyok hasznlata szebb URL-t ad a blog-odnak, s a web-es robotok (pl: google)is knnyebben indexelik. A webszervernek tmogatnia kell a "mod_rewrite" vagy a "AllowOverride All" belltst a serendipity knyvtradhoz. Az alaprtelmezett bellts az automatikus rzkels (autodetect))');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Kp konvertl belltsok');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Globlis belltsok arrl, hogy a serendipity hogyan kezelje a kpeket');
@define('INSTALL_IMAGEMAGICK', 'ImageMagick hasznlata');
@define('INSTALL_IMAGEMAGICK_DESC', 'Van-e a szerveren ImageMagick teleptve, s szeretn-e ezt hasznlni a kpek tmretezshez?');
@define('INSTALL_IMAGEMAGICKPATH', 'A futtathat fjl elrsi tvonala');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Az Imagemagic program tvonala s fjlneve');
@define('INSTALL_THUMBSUFFIX', 'A generlt elnzeti kpek eltagja');
@define('INSTALL_THUMBSUFFIX_DESC', 'A kpekbl generlt elnzeti kpek ilyen nevek lesznek: eredetinv.[eltag].kiterj');
@define('INSTALL_THUMBWIDTH', 'Elnzeti kp mretek');
@define('INSTALL_THUMBWIDTH_DESC', 'Az automatikusan generlt elnzeti kpek szlessgnek maximuma');
@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
@define('INSTALL_THUMBDIM_WIDTH', 'Width');
@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" only limit the chosen dimension, so the other could be larger than the max size.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Szemlyes adatok');
@define('USERCONF_CAT_PERSONAL_DESC', 'Itt vltoztatod meg a szemlyes adatait');
@define('USERCONF_USERNAME', 'Felhasznl nv');
@define('USERCONF_USERNAME_DESC', 'Ezzel a nvvel jelentkezhetsz be');
@define('USERCONF_PASSWORD', 'Jelsz');
@define('USERCONF_PASSWORD_DESC', 'A belpshez hasznlt jelsz');
@define('USERCONF_EMAIL', 'Email cm');
@define('USERCONF_EMAIL_DESC', 'Az email cmed');
@define('USERCONF_SENDCOMMENTS', 'Hozzszlsok elkldse?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Szeretnl kapni emailt ha valamelyik bejegyzshez hozzszls rkezik?');
@define('USERCONF_SENDTRACKBACKS', 'Kldjnk rtestst visszahivatkozskor?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Szeretnl kapni emailt, ha valaki visszahivatkozik valamelyik bejegyzsedre?');
@define('USERCONF_ALLOWPUBLISH', 'Jogok: Bejegyzs kzzttele?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Ez a felhasznl jogosult a bejegyzsek kzzttelre?');
@define('SUCCESS', 'A mvelet siker');
@define('POWERED_BY_SHOW_TEXT', 'A "Serendipity" felirat szvegknt mutatsa');
@define('POWERED_BY_SHOW_TEXT_DESC', 'A "Serendipity Weblog" feliratot szvegknt mutatja');
@define('POWERED_BY_SHOW_IMAGE', 'A "Serendipity" felirat megjelentse logo-val');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Megjelenti a Serendipity logo-t');
@define('PLUGIN_ITEM_DISPLAY', 'Hol legyen lthat az elem?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Rszletes oldal');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'ttekint oldal');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Mindkett');
@define('RSS_IMPORT_CATEGORY', 'E kategria hasznlata az olyan importlt bejegyzsekhez, amelyek nem tartoznak sehova');

@define('COMMENTS_WILL_BE_MODERATED', 'A hozzszlsok moderlson esnek t megjelens eltt.');
@define('YOU_HAVE_THESE_OPTIONS', 'A kvetkez opcik rhetk el:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Figyelem: Ezt a bejegyzst el kell fogadni mieltt megjelenhetne');
@define('DELETE_COMMENT', 'Hozzszls trlse');
@define('APPROVE_COMMENT', 'Hozzszls elfogadsa');
@define('REQUIRES_REVIEW', 'Szksges az elzetes tnzs');
@define('COMMENT_APPROVED', 'A kvetkez hozzszlst sikeresen elfogadtuk: #%s');
@define('COMMENT_DELETED', 'A kvetkez hozzszlst sikeresen trltk: #%s');
@define('COMMENTS_MODERATE', 'A hozzszlsokat s a visszahivatkozsokat moderlni kell megjelens eltt.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Figyelem: Ezt a visszahivatkozst el kell fogadni mieltt megjelenhetne');
@define('DELETE_TRACKBACK', 'Visszahivatkozs trlse');
@define('APPROVE_TRACKBACK', 'Visszahivatkozs elfogadsa');
@define('TRACKBACK_APPROVED', 'A visszahivatkozst sikeresen elfogadtuk: #%s');
@define('TRACKBACK_DELETED', 'A visszahivatkozst sikeresen trltk: #%s');
@define('VIEW', 'Megtekint');
@define('COMMENT_ALREADY_APPROVED', 'A hozzszls mr elfogadott: #%s');
@define('COMMENT_EDITED', 'A kivlasztott hozzszls mdostva lett');
@define('HIDE', 'Elrejt');
@define('VIEW_EXTENDED_ENTRY', '"%s" tovbb olvassa');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Ez a link nem szolgl tartalom megjelentsre. A visszahivatkozshoz hasznlhat URL-t tartalmazza ehhez a bejegyzshez. Ezt hasznld a sajt blogodban az erre a bejegyzsre val visszahivatkozskor. Az URL msolshoz kattints rajta jobb egrgombbal, majd vlaszd a "Hivatkozs cmnek msolsa" funkcit.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Https hasznlata bejelentkezshez');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'A bejelentkezsi hivatkozs https cmre fog mutatni. A bngsznek tmogatnia kell ezt!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Legyenek a kls helyre val hivatkozsok kattinthatak?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nem": a nem ellenrztt kls hivatkozsok (leggyakoribb kilpk, leggyakoribb visszahivatkozk, hozzszlsok) sima szvegknt jelennek meg, azaz nem kattinthatak, megelzve ezzel pl. a google spam-et (ajnlott). "igen": a nem ellenrztt kls hivatkozsok kattinthat hivatkozsknt val megjelentse. Felldefinilhat a marg modul belltsainl!');
@define('PAGE_BROWSE_COMMENTS', '%s oldal ennyibl: %s, sszesen ennyi bejegyzs: %s');
@define('FILTERS', 'Szrk');
@define('FIND_ENTRIES', 'Bejegyzs keresse');
@define('FIND_COMMENTS', 'Hozzszls keresse');
@define('FIND_MEDIA', 'Mdia objektum keresse');
@define('FILTER_DIRECTORY', 'Knyvtr');
@define('SORT_BY', 'Rendezs a kvetkez szerint');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Nem sikerlt visszahivatkozst kldeni: nem sikerlt a csatlakozs ide: %s ezen a porton: %d');
@define('MEDIA', 'Mdia');
@define('MEDIA_LIBRARY', 'Mdia knyvtr');
@define('ADD_MEDIA', 'Mdia hozzadsa');
@define('ENTER_MEDIA_URL', 'Add meg a letltend fjlra mutat hivatkozst:');
@define('ENTER_MEDIA_UPLOAD', 'Vlassza ki a feltltend fjlt:');
@define('SAVE_FILE_AS', 'Fjl mentse a kvetkez nven:');
@define('STORE_IN_DIRECTORY', 'Trols a kvetkez knyvtrban: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Fjl hozzadsa a mdia trolhoz:</b><p>Itt tlthetsz fel mdiafjlokat, vagy megmondhatod hogy honnan tltsem le ket! Ha nincs meg egy bizonyos kp, <a href="http://images.google.com" target="_blank">keress r a google-t hasznlva</a> az elkpzelsednek megfelelen. Az eredmnyek gyakran hasznosak s viccesek :) De vigyzz, a legtbb kp szerzi jogvdelem alatt ll, gy mieltt hasznlnd krdezz r.</p><p><b>Vlassz a lehetsgek kzl:</b></p><br/>');
@define('MEDIA_RENAME', 'Fjl tnevezse');
@define('IMAGE_RESIZE', 'Kp tmretezse');
@define('MEDIA_DELETE', 'Fjl trlse');
@define('FILES_PER_PAGE', 'Oldalanknt megjelen fjlok');
@define('CLICK_FILE_TO_INSERT', 'Kattints a beillesztend fjlra:');
@define('SELECT_FILE', 'Vlassz ki fjlt a beillesztshez');
@define('MEDIA_FULLSIZE', 'Teljes mret');
@define('CALENDAR_BOW_DESC', 'A ht azon napja, amely a kezdnapnak szmt. Alaprtelmezs: Htf');
@define('SUPERUSER', 'Blog adminisztrci');
@define('ALLOWS_YOU_BLAHBLAH', 'A margn biztost hivatkozst a blog adminisztrlshoz');
@define('CALENDAR', 'Naptr');
@define('SUPERUSER_OPEN_ADMIN', 'Adminisztrci megnyitsa');
@define('SUPERUSER_OPEN_LOGIN', 'Bejelentkez ablak megnyitsa');
@define('INVERT_SELECTIONS', 'Kijells megfordtsa');
@define('COMMENTS_DELETE_CONFIRM', 'Biztosan trld a kijellt hozzszlsokat?');
@define('COMMENT_DELETE_CONFIRM', 'Biztosan trld a kvetkez hozzszlst: #%d, ettl a kldtl: %s ?');
@define('DELETE_SELECTED_COMMENTS', 'Kijellt hozzszlsok trlse');
@define('VIEW_COMMENT', 'Hozzszls megtekintse');
@define('VIEW_ENTRY', 'Bejegyzs megtekintse');
@define('DELETE_FILE_FAIL' , 'Nem sikerlt a fjl trlse: <b>%s</b>');
@define('DELETE_THUMBNAIL', 'A kvetkez elnzeti kp trlse: <b>%s</b>');
@define('DELETE_FILE', 'A kvetkez fjlt trltem: <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'A kvetkez fjl trlsre kszlsz: <b>%s</b><br />Ha van olyan bejegyzs ahol ezt hasznlod, akkor gy trtt hivatkozsok vagy hinyz kpek lesznek<br />Biztosan folytatod?<br /><br />');
@define('TRACKBACK_SENDING', 'Visszahivatkozs kldse ide: %s...');
@define('TRACKBACK_SENT', 'A visszahivatkozs sikeres');
@define('TRACKBACK_FAILED', 'A visszahivatkozs nem sikerlt: %s');
@define('TRACKBACK_NOT_FOUND', 'A visszahivatkozs URL nem tallhat.');
@define('TRACKBACK_URI_MISMATCH', 'Az automatikusan felismert visszahivatkozsi URL nem egyezik meg a cl URL-el.');
@define('TRACKBACK_CHECKING', '<u>%s</u> ellenrzse lehetsges visszshivatkozsokra ...');
@define('TRACKBACK_NO_DATA', 'Nem tallhat adat');
@define('TRACKBACK_SIZE', 'A cl URL meghaladta a maximlis fjlmretet: %s bjt.');
@define('COMMENTS_VIEWMODE_THREADED', 'Logikai sorrend');
@define('COMMENTS_VIEWMODE_LINEAR', 'Folyamatos');
@define('DISPLAY_COMMENTS_AS', 'A hozzszlsok megjelentse gy:');
@define('COMMENTS_FILTER_SHOW', 'Mutat');
@define('COMMENTS_FILTER_ALL', 'sszes');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Elfogadott');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Mg el nem fogadott');
@define('RSS_IMPORT_BODYONLY', 'Az sszes szveg kerljn a trzsbe, ne legyen kls bejegyzsekre szedve.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Az egsz bejegyzs RSS hrcsatornban mutatsa a kls szvegekkel egytt.');
@define('WEEK', 'Ht');
@define('WEEKS', 'Hetek');
@define('MONTHS', 'Hnapok');
@define('DAYS', 'Napok');
@define('ARCHIVE_FREQUENCY', 'Naptri bejegyzs srsge');
@define('ARCHIVE_FREQUENCY_DESC', 'A bejegyzsek kzti naptri intervallum');
@define('ARCHIVE_COUNT', 'A listban lv elemek szma');
@define('ARCHIVE_COUNT_DESC', 'A megjelentend hnapok, hetek, napok szma');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Lentebb tallhat a teleptett modulok listja');
@define('SIDEBAR_PLUGIN', 'Marg modul');
@define('EVENT_PLUGIN', 'Esemny modul');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Kattints ide j %s teleptshez');
@define('VERSION', 'verzi');
@define('INSTALL', 'Telepts');
@define('ALREADY_INSTALLED', 'Mr teleptett');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vlaszd ki a teleptend modult');
@define('INSTALL_OFFSET', 'Szerver id eltolds');
@define('STICKY_POSTINGS', 'Ragads beklds');
@define('INSTALL_FETCHLIMIT', 'A foldalon megjelentend bejegyzsek');
@define('INSTALL_FETCHLIMIT_DESC', 'A foldalon lv oldalakon megjelen bejegyzsek szma');
@define('IMPORT_ENTRIES', 'Adat importlsa');
@define('EXPORT_ENTRIES', 'Bejegyzsek exportlsa');
@define('IMPORT_WELCOME', 'dvzlm a Serendipity importl eszkzben');
@define('IMPORT_WHAT_CAN', 'Itt ms blog alkalmazs bejegyzseit importlhatja');
@define('IMPORT_SELECT', 'Vlassza ki, hogy melyik blog szoftverbl szeretne importlni');
@define('IMPORT_PLEASE_ENTER', 'Add meg a szksges adatokat');
@define('IMPORT_NOW', 'Importls!');
@define('IMPORT_STARTING', 'Importls elkezdse ...');
@define('IMPORT_FAILED', 'Az import nem sikerlt');
@define('IMPORT_DONE', 'Az import sikeres');
@define('IMPORT_WEBLOG_APP', 'Weblog program');
@define('IMPORT_NOTES', 'Megjegyzs:');
@define('EXPORT_FEED', 'Teljes RSS hrcsatorna exportja');
@define('STATUS', 'Importls utni sttusz');
@define('IMPORT_GENERIC_RSS', 'ltalnos RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'Visszahivatkozs kldse a bejegyzsekben tallhat hivatkozsokra.');
@define('WELCOME_TO_ADMIN', 'dvzlm a Serendipity adminisztrtori felletn.');
@define('PLEASE_ENTER_CREDENTIALS', 'Add meg az azonostshoz szksges adataidat.');
@define('ADMIN_FOOTER_POWERED_BY', 'Powered by Serendipity %s and PHP %s');
@define('INSTALL_USEGZIP', 'Gzip tmrtett oldalak hasznlata');
@define('INSTALL_USEGZIP_DESC', 'Az oldalak kiszolglsnak gyorstshoz, a ltogatnak kldtt oldalakat tmrthetjk, ha a bngsz tmogatja ezt. Ajnlott bellts.');
@define('INSTALL_SHOWFUTURE', 'Jvbeli bejegyzsek mutatsa');
@define('INSTALL_SHOWFUTURE_DESC', 'Ha ez engedlyezve van, akkor a jvbeni bejegyzsek is lthatak lesznek. Alaprtelmezsben ezeket elrejtjk, s cask akkor kerlnek megmutatsra, ha eljn a publiklsi dtum.');
@define('INSTALL_DBPERSISTENT', 'lland kapcsolat hasznlata');
@define('INSTALL_DBPERSISTENT_DESC', 'Engedlyezd az lland adatbziskapcsolat hasznlathoz. <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">Itt olvashatsz errl tbbet</a>. Normlis esetben ez nem szksges');
@define('NO_IMAGES_FOUND', 'Nem tallhat kp');
@define('PERSONAL_SETTINGS', 'Szemlyes belltsok');
@define('REFERER', 'Hivatkoz');
@define('NOT_FOUND', 'Nincs tallat');
@define('WRITABLE', 'rhat');
@define('NOT_WRITABLE', 'Nem rhat');
@define('PROBLEM_DIAGNOSTIC', 'Az ellenrzsek hibja miatt nem folytathatod a teleptst, addig amg ezeket nem javtod');
@define('SELECT_INSTALLATION_TYPE', 'Vlaszd ki a telepts tpust');
@define('WELCOME_TO_INSTALLATION', 'dvzllek a Serendipity teleptjben');
@define('FIRST_WE_TAKE_A_LOOK', 'Elszr meg kell vizsgljuk a jelenlegi belltsokat ahhoz hogy feltrkpezzk az esetleges kompatibilitsi problmkat');
@define('ERRORS_ARE_DISPLAYED_IN', 'A hibkat gy jelljk: %s, a javaslatokat gy: %s a sikert pedig gy: %s');
@define('RED', 'priros');
@define('YELLOW', 'srga');
@define('GREEN', 'zld');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s teleptsi ellenrzs jelents');
@define('RECOMMENDED', 'Javasolt');
@define('ACTUAL', 'Aktulis');
@define('PHPINI_CONFIGURATION', 'php.ini konfigurci');
@define('PHP_INSTALLATION', 'PHP telepts');
@define('THEY_DO', 'lteznek');
@define('THEY_DONT', 'nem lteznek');
@define('SIMPLE_INSTALLATION', 'Egyszer telepts');
@define('EXPERT_INSTALLATION', 'Halad telepts');
@define('COMPLETE_INSTALLATION', 'Telepts befejezse');
@define('WONT_INSTALL_DB_AGAIN', 'nem szksges az adatbzis jrateleptse');
@define('CHECK_DATABASE_EXISTS', 'Adatbzis, s adatbzis tblk ltezsnek ellenrzse');
@define('CREATING_PRIMARY_AUTHOR', 'Elsdleges szerz ltrehozsa \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Alaprtelmezett sablonok belltsa');
@define('INSTALLING_DEFAULT_PLUGINS', 'Alaprtelmezett modulok teleptse');
@define('SERENDIPITY_INSTALLED', 'A Serendipity-t sikeresen teleptettk');
@define('VISIT_BLOG_HERE', 'Itt ltogathatod meg a blog-odat');
@define('THANK_YOU_FOR_CHOOSING', 'Ksznjk hogy a Serendipity-t vlasztottad');
@define('ERROR_DETECTED_IN_INSTALL', 'Hiba lpett fel a telepts kzben');
@define('OPERATING_SYSTEM', 'Opercis rendszer');
@define('WEBSERVER_SAPI', 'Web kiszolgl SAPI');
@define('TEMPLATE_SET', 'Az alaprtelmezett sablonod belltsra kerlt: \'%s\'');
@define('SEARCH_ERROR', 'A keres funkci nem mkdik megfelelen. Jelezd a blog adminisztrtornak: Ez az adatbzis indexek hinya miatt lehet. MySQL esetben az adatbzis felhasznlnak kell ezt futtatnia a megfelel jogosultsgokkal: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Az adatbzis a kvetkez hibt adta: <pre>%s</pre>');
@define('EDIT_THIS_CAT', '"%s" szerkesztse');
@define('CATEGORY_REMAINING', 'Kategria trlse, s a hozz kapcsold bejegyzsek hozzrendelse ehhez a kategrihoz:');
@define('CATEGORY_INDEX', 'A bejegyzsek szmra elrhet kategrik');
@define('NO_CATEGORIES', 'Nincsenek kategrik');
@define('RESET_DATE', 'Dtum visszalltsa');
@define('RESET_DATE_DESC', 'Kattints ide, hogy a dtumot visszalltsd a jelenlegi dtumra');
@define('PROBLEM_PERMISSIONS_HOWTO', 'A jogosultsgok a kvetkez paranccsal llthatk be: `<em>%s</em>` a hibs knyvtron, vagy FTP programmal is bellthatk');
@define('WARNING_TEMPLATE_DEPRECATED', 'Figyelem: A jelenlegi sablonod elavult sablon metdust hasznl, ajnlott a frisstse');
@define('ENTRY_PUBLISHED_FUTURE', 'Ez a bejegyzs mg nincs publiklva.');
@define('ENTRIES_BY', '%s bejegyzsei');
@define('PREVIOUS', 'Elz');
@define('NEXT', 'Kvetkez');
@define('APPROVE', 'Elfogad');
@define('DO_MARKUP_DESCRIPTION', 'Szvegjellsek transzformlsa (vigyorg fejek, rvidtsre hasznlt jellsek a kvetkez mdon: *, /, _, ...). Ezt tiltva, a szvegben nem lehet semmilyen HTML kd.');
@define('CATEGORY_ALREADY_EXIST', 'Ltezik mr kategria a kvetkez nvvel: "%s"');
@define('ERROR_FILE_FORBIDDEN', 'Nincs jogosultsgod aktv bejegyzs felvitelre');
@define('ADMIN', 'Adminisztrci');
@define('ADMIN_FRONTPAGE', 'Kezdlap');
@define('QUOTE', 'Idz');
@define('IFRAME_SAVE', 'A Serendipity most elmenti a bejegyzsedet, visszahivatkozsokat frisst s vgrehajtja a szksges XML-RPC hvsokat. Ez elrathat egy ideig ..');
@define('IFRAME_SAVE_DRAFT', 'A bejegyzs piszkozata mentsre kerlt.');
@define('IFRAME_PREVIEW', 'A Serendipity a bejegyzs elnzett generlja ...');
@define('IFRAME_WARNING', 'A bngszd nem tmogatja az iframe-eket. Nyisd meg a serendipity_config.inc.php fjlt s lltsd t a  $serendipity[\'use_iframe\'] vltozt FALSE-ra.');
@define('NONE', 'egyik sem');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Alaprtelmezett belltsok j bejegyzsekhez');
@define('UPGRADE', 'Frissts');
@define('UPGRADE_TO_VERSION', 'Frissts erre a verzira: %s');
@define('DELETE_DIRECTORY', 'Knyvtr trlse');
@define('DELETE_DIRECTORY_DESC', 'Trlni kszl egy knyvtrat, amelyben mdia fjlok vannak. Lehetsges hogy ezekre hivatkozik bejegyzsekbl is.');
@define('FORCE_DELETE', 'Az SSZES fjl trlse a knyvtrbl, azokat is amelyeket a Serendipity nem ismer');
@define('CREATE_DIRECTORY', 'Knyvtr ltrehozsa');
@define('CREATE_NEW_DIRECTORY', 'j knyvtr ltrehozsa');
@define('CREATE_DIRECTORY_DESC', 'j knyvtrat hozhat ltre a mdia fjlok szmra. rj be egy nevet, s ha kell vlassz szlknyvtrat.');
@define('BASE_DIRECTORY', 'Alap knyvtr');
@define('USERLEVEL_EDITOR_DESC', 'Egyszer szerkeszt');
@define('USERLEVEL_CHIEF_DESC', 'Fszerkeszt');
@define('USERLEVEL_ADMIN_DESC', 'Adminisztrtor');
@define('USERCONF_USERLEVEL', 'Hozzfrsi szint');
@define('USERCONF_USERLEVEL_DESC', 'Ez a szint hatrozza meg, hogy a szerkesztnek milyen jogosultsgai vannak a blog-hoz');
@define('USER_SELF_INFO', 'Bejelentkezve mint %s (%s)');
@define('ADMIN_ENTRIES', 'Bejegyzsek');
@define('RECHECK_INSTALLATION', 'Telepts jraellenrzse');
@define('IMAGICK_EXEC_ERROR', 'Nem sikerlt futtatni a kvetkezt: "%s", hiba: %s, visszatrsi rtk: %d');
@define('INSTALL_OFFSET_DESC', 'Add meg az idklnbsget a szerveren lv id (jelenlegi: %clock%), s az ltalad hasznlni kvnt idpont kztt');
@define('UNMET_REQUIREMENTS', 'Fggsgi hibk: %s');
@define('CHARSET', 'Karakterkdols');
@define('AUTOLANG', 'A ltogat bngszjben belltott nyelv hasznlata');
@define('AUTOLANG_DESC', 'Ha ez "igen"-re van lltva, akkor az oldal megtekintjnek a bngszjben megadott nyelv lesz aktv a bejegyzseknl s a felleten.');
@define('INSTALL_AUTODETECT_URL', 'HTTP-Hoszt automatikus meghatrozsa');
@define('INSTALL_AUTODETECT_URL_DESC', 'Ha ez "igen"-re van lltva, akkor a ltogat ltal hasznlt domain nv kerl hasznlatra  az ltalad belltott BaseURL helyett. Ezzel a belltssal tbb domain-es krnyezetben is hasznlhatod a Serendipity blog-ot, gy nem okoz gondot a linkek kezelse.');
@define('CONVERT_HTMLENTITIES', 'A HTML bejegyzsek automatikus konvertlsa?');
@define('EMPTY_SETTING', 'Nem adtl meg rtket ehhez: "%s"!');
@define('USERCONF_REALNAME', 'Valdi nv');
@define('USERCONF_REALNAME_DESC', 'A szerz teljes neve. Ezt ltjk az olvask.'); 
@define('HOTLINK_DONE', 'Fjl kzvetlen hivatkozs ltrehozva.<br />Ksz.');
@define('ENTER_MEDIA_URL_METHOD', 'Letltsi md:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Megjegyzs: ha a kzvetlen hivatkozst vlasztod, bizonyosodj meg arrl, hogy van-e jogod ehhez, vagy a szerver ahova mutatsz a tid. Ezzel a mdszerrel gy jelenthetsz meg kpeket, hogy azok nem kerlnek hozzd lementsre.');
@define('MEDIA_HOTLINKED', 'kzvetlenl hivatkozva');
@define('FETCH_METHOD_IMAGE', 'Kp letltse a szerveredre');
@define('FETCH_METHOD_HOTLINK', 'Kzvetlen hivatkozs szerverre');
@define('DELETE_HOTLINK_FILE', 'Ezt a kzvetlen hivatkozst hasznl fjlt trltk <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'E-mail cmek mutatsa?');
@define('IMAGE_MORE_INPUT', 'Tovbbi kpek hozzadsa');
@define('BACKEND_TITLE', 'Tovbbi informci a modul belltsainl');
@define('BACKEND_TITLE_FOR_NUGGET', 'Itt sajt szveget adhatsz meg, ami megjelenik a modul bellt kpernyn a HTML Nugget modulnl a lerssal egytt. Ha tbb HTML Nugget ltezik cm nlkl, ez segthet ket megklnbztetni.');
@define('CATEGORIES_ALLOW_SELECT', 'A ltogatk megjelenthetnek tbb kategrit egyszerre?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Ha ezt engedlyezed, akkor a kategria margnl, minden kategria mellett lesz egy jellngyzet. A ltogatk gy vlaszthatjk ki azokat a kategrikat, amelyekbe tartoz bejegyzseket szeretnk ltni.');
@define('PAGE_BROWSE_PLUGINS', '%s oldal ennyibl: %s, sszes modul: %s');
@define('INSTALL_CAT_PERMALINKS', 'Permanens hivatkozsok');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Klnbz URL mintkat lehet definilni a permanens hivatkozsokhoz, amiket azutn a blog-ban hasznlhatsz. Az alaprtelmezett hasznlata ajnlott; ha nem azt hasznlod, akkor prbld ezt az rtket: %id% , amennyiben lehet, ahhoz hogy a Serendipity-nek ne kelljen lekrdeznie az URL-t az adatbzisbl.');
@define('INSTALL_PERMALINK', 'Bejegyzsre vonatkoz permanens hivatkozs URL struktrja');
@define('INSTALL_PERMALINK_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a bejegyzsek elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %title%, %day%, %month%, %year% s egyb karaktereket is.');
@define('INSTALL_PERMALINK_AUTHOR', 'Szerzre vonatkoz permanens hivatkozs URL struktrja');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a szerzre mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %realname%, %username%, %email% s egyb karaktereket is.');
@define('INSTALL_PERMALINK_CATEGORY', 'Kategrira vonatkoz permanens hivatkozs URL struktrja');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a kategrira mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %name%, %parentname%, %description% s egyb karaktereket is.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS hrcsatornra vonatkoz permanens hivatkozs URL struktrja');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan az RSS hrcsatornra mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %name%, %description% s egyb karaktereket is.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Archvumok tvonala');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Archvum tvonala');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Kategrik tvonala');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'tvonal a hozzszlsrl val leiratkozshoz');
@define('INSTALL_PERMALINK_DELETEPATH', 'tvonal a hozzszls trlshez');
@define('INSTALL_PERMALINK_APPROVEPATH', 'tvonal a hozzszls elfogadshoz');
@define('INSTALL_PERMALINK_FEEDSPATH', 'tvonal az RSS hrcsatornkhoz');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Modul tvonala');
@define('INSTALL_PERMALINK_ADMINPATH', 'Adminisztrci tvonala');
@define('INSTALL_PERMALINK_SEARCHPATH', 'tvonal a keresshez');
@define('INSTALL_CAL', 'Naptr tpus');
@define('INSTALL_CAL_DESC', 'Vlaszd ki a kvnt naptr formtumt');
@define('REPLY', 'Vlasz');
@define('USERCONF_GROUPS', 'Csoporttagsg');
@define('USERCONF_GROUPS_DESC', 'Ez a felhasznl a kvetkez csoportok tagja. Tbb csoportba is tartozhat.');
@define('MANAGE_GROUPS', 'Csoportok kezelse');
@define('DELETED_GROUP', 'A csoport trlve: #%d %s.');
@define('CREATED_GROUP', 'Az j csoportot ltrehoztuk: %s');
@define('MODIFIED_GROUP', 'A kvetkez csoport tulajdonsgait megvltoztattuk %s');
@define('GROUP', 'Csoport');
@define('CREATE_NEW_GROUP', 'j csoport ltrehozsa');
@define('DELETE_GROUP', 'A kvetkez csoport trlsre kszlsz: #%d %s. Biztos vagy benne?');
@define('USERLEVEL_OBSOLETE', 'Megjegyzs: A felhasznl szint attribtumok a visszafele kompatibilits, nhny modul s az azonosts nhny esete miatt szksgesek. A felhasznlk jogosultsga a csoporttagsgon keresztl llthat be!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner azonost');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'A hrcsatorna azonostja, amelyet publiklni szeretnl');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner kp');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'A kp neve amit meg szeretnl jelenteni (hagyd resen a szmllhoz), a feedburner.com oldalrl, pl.: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner cm');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Cm (ha van) amit a kp mellett jelentnk meg');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner kp felirat');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Szveg (ha van) amit a kp fl llva jelentnk meg');
@define('SEARCH_TOO_SHORT', 'A keressi kritriumnak 3 karakternl tbbnek kell lennie. A *-al a szavak vgn rvidtheted ket, mint: s9y* ahhoz hogy a keres rvidebb szavakat hasznljon.');
@define('INSTALL_DBPORT', 'Adatbzis port');
@define('INSTALL_DBPORT_DESC', 'Az adatbzishoz val kapcsoldskor hasznlt port');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: External Services');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Fellet: Kpessgek');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Fellet: Teljes modulok');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Fellet: Nzetek');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Fellet: Bejegyzshez kapcsold');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Httr: Szerkeszt');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Httr: Felhasznlkezels');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Httr: Meta informcik');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Httr: Sablonok');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Httr: Kpessgek');
@define('PLUGIN_GROUP_IMAGES', 'Kpek');
@define('PLUGIN_GROUP_ANTISPAM', 'Spamszr');
@define('PLUGIN_GROUP_MARKUP', 'Kiemels');
@define('PLUGIN_GROUP_STATISTICS', 'Statisztika');
@define('PERMISSION_PERSONALCONFIGURATION', 'Szemlyes belltsok elrse');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'Felhasznli szint vltoztatsa');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'A "nem vehet fel bejegyzst" vltoztatsa');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'Bejegyzs publiklsi jogosultsg vltoztatsa');
@define('PERMISSION_SITECONFIGURATION', 'Rendszer-konfigurcihoz hozzfr');
@define('PERMISSION_BLOGCONFIGURATION', 'Blog specifikus belltsokhoz hozzfr');
@define('PERMISSION_ADMINENTRIES', 'Bejegyzsek adminisztrlsa');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'Ms felhasznlk bejegyzseinek adminisztrlsa');
@define('PERMISSION_ADMINIMPORT', 'Bejegyzsek importlsa');
@define('PERMISSION_ADMINCATEGORIES', 'Kategrik adminisztrlsa');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'Ms felhasznlk kategriinak adminisztrlsa');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'Kategrik trlse');
@define('PERMISSION_ADMINUSERS', 'Felhasznlk adminisztrlsa');
@define('PERMISSION_ADMINUSERSDELETE', 'Felhasznlk trlse');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'Felhasznli szint megvltoztatsa');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'A csoportodban lv felhasznlk adminisztrlsa');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'A csoportodba nem tartoz felhasznlk adminisztrlsa');
@define('PERMISSION_ADMINUSERSCREATENEW', 'Felhasznlk ltrehozsa');
@define('PERMISSION_ADMINUSERSGROUPS', 'Felhasznli csoportok adminisztrlsa');
@define('PERMISSION_ADMINPLUGINS', 'Modulok adminisztrlsa');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'Ms felhasznlk moduljainak adminisztrlsa');
@define('PERMISSION_ADMINIMAGES', 'Mdia fjlok adminisztrlsa');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'Mdia knyvtrak adminisztrlsa');
@define('PERMISSION_ADMINIMAGESADD', 'j mdia fjlok hozzadsa');
@define('PERMISSION_ADMINIMAGESDELETE', 'Mdia fjlok trlse');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'Ms felhasznlk mdia fjljainak adminisztrlsa');
@define('PERMISSION_ADMINIMAGESVIEW', 'Mdia fjlok megtekintse');
@define('PERMISSION_ADMINIMAGESSYNC', 'Elnzeti kpek szinkronizlsa');
@define('PERMISSION_ADMINCOMMENTS', 'Hozzszlsok adminisztrlsa');
@define('PERMISSION_ADMINTEMPLATES', 'Sablonok adminisztrlsa');
@define('INSTALL_BLOG_EMAIL', 'A Blog email cme');
@define('INSTALL_BLOG_EMAIL_DESC', 'Itt adhat meg az az email cm, ami a kimen levelek "Kld" rszben lesz megtallhat. rdemes vals email cmet megadni itt, mert sok levelez szerver ellenrzi a kld email cm rvnyessgt.');
@define('CATEGORIES_PARENT_BASE', 'Csak ezen kategrik mutatsa ...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Vlaszthatsz szl kategrit, gy csak az al tartoz gyermekkategrik ltszdnak.');
@define('CATEGORIES_HIDE_PARALLEL', 'A kategria fba nem tartoz kategrik elrejtse');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Ha nem szeretnd hogy azok a kategrik is megjelenjenek, amelyek ms kategriafhoz tartoznak, engedlyezheted. Ennek csak akkor van jelentsge, ha a "multi-blog"-al egytt hasznlod, a "Kategrik tulajdonsgai/sablonjai" modulban.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'Ms felhasznlk mdia fjljainak megtekintse');
@define('CHARSET_NATIVE', 'Natv (beptett)');
@define('INSTALL_CHARSET', 'Karakterkdols vlasztsa');
@define('INSTALL_CHARSET_DESC', 'Itt bellthatod az UTF-8, vagy a natv (ISO, EUC, ...) karakterkdolst. Nhny nyelvnek csak UTF-8 lekpezse ltezik, gy itt a natvot nem rdemes vlasztani. Az UTF-8 ajnlott j teleptskor. Ne vltoztasd meg ezt akkor, ha mr vannak bejegyzseid specilis karakterekkel - mert gy hibs karakterek jelenhetnek meg. Itt olvashatsz errl tbbet: http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Modul API hook (kamp) engedlyezse');
@define('CALENDAR_EXTEVENT_DESC', 'Ha ezt engedlyezed, akkor a modulok megjelenthetik a naptrban a sajt esemnyeiket. Akkor engedlyezd, ha van olyan modulod, amelyiknek szksge van erre, klnben csak rontja a teljestmnyt.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'Az XML-RPC API Interfsz a Serendipity-hez, tbb nincs hasznlatban, mivel vannak biztonsgi problmi, s nem sokan hasznljk. gy teleptened kell az XML-RPC modult ahhoz hogy hasznld az XML-RPC API-t. Az alkalmazsban hasznland URL nem vltozik - telepts utn hasznlhat.');
@define('PERM_READ', 'Olvassi jogosultsg');
@define('PERM_WRITE', 'rsi jogosultsg');

@define('PERM_DENIED', 'Hozzfrs megtagadva.');
@define('INSTALL_ACL', 'Olvassi jogosultsgok bekapcsolsa a kategrikon');
@define('INSTALL_ACL_DESC', 'Ha engedlyezed, akkor a kategrikra alkalmazott olvassi jogosultsgok minden alkalommal ellenrzsre kerlnek amikor egy ltogat megtekinti az oldalt. Ha nincs engedlyezve, az olvassi jogosultsgok nem kerlnek ellenrzsre, de cserbe gyorsabb lesz a mkds. gy ha nincs szksged erre, ne engedlyezd.');
@define('PLUGIN_API_VALIDATE_ERROR', 'A bellts szintaktikja hibs erre az opcira: "%s". A kvetkez tpusnak kell lennie: "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Rgi jelsz');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Ha a mezben megvltoztatod a jelszt, itt meg kell adnod a jelenlegit.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Helytelenl adtad meg a jelenlegi jelszt, gy nem vltoztathatod meg. A belltsokat nem mentettk.');
@define('ERROR_XSRF', 'A bngszd nem kldtt rvnyes HTTP-Hivatkoz szveget. Ez tbb okbl lehet, pl. rosszul belltott bngsz, proxy, vagy egy Cross Site Request Forgery (XSRF) tmads ldozata lettl. A krt mvelet nem hajthat vgre.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahol az egyes felhasznlk RSS hrcsatorni megtekinthetk. A kvetkez vltozkat hasznlhatod: %id%, %realname%, %username%, %email% s egyb karaktereket.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'A szerzre hivatkoz permanens hivatkozs RSS hrcsatorna-beli struktrja');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'tvonal a szerzkhz');
@define('AUTHORS', 'Szerzk');
@define('AUTHORS_ALLOW_SELECT', 'A ltogatk tbb szerzt is megjelenthetnek egyszerre?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Ha ezt engedlyezed, akkor ebben a margban, minden szerz mellett lesz egy jellngyzet. A ltogatk gy vlaszthatjk ki azokat a szerzket, akiknek a bejegyzseit szeretnk ltni.');
@define('AUTHOR_PLUGIN_DESC', 'Szerzk listjnak mutatsa');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Smarty-sablonok engedlyezse?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Ha ezt engedlyezed, a modul Smarty-sablont hasznl a kategrialista megjelentshez. gy a kinzetet a "plugin_categories.tpl" sablonban is mdosthatod. Ez befolysolja a teljestmnyt, gy ha nincs szksged erre ne engedlyezd.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Mutassuk a kategrikba tartoz bejegyzsek szmt?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Mutassuk a szerzkhz tartoz bejegyzsek szmt a szerz neve mellett?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Ha ezt engedlyezed, akkor a szerz ltal ltrehozott bejegyzsek szma, a neve mellett jelenik meg zrjelben.');
@define('CUSTOM_ADMIN_INTERFACE', 'Egyedi adminisztrcis fellet rhet el');

@define('COMMENT_NOT_ADDED', 'A hozzszlst nem tudtuk felvenni, mert vagy rvnytelen adatot adtl meg, vagy ez le van tiltva, vagy a spamszr kiszrte az zenetet.');
@define('INSTALL_TRACKREF', 'Engedlyezzk a hivatkozk ellenrzst?');
@define('INSTALL_TRACKREF_DESC', 'Ha ezt engedlyezed, ltod majd, hogy mely oldalak hivatkoznak a bejegyzseidre. Manapsg ezt gyakran hasznljk spammerek, gy rdemes ezt tiltani.');
@define('CATEGORIES_HIDE_PARENT', 'A kijellt szl kategria eltntetse');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Ha a kategrik listjt egy bizonyos kategrira szkted, akkor a szl kategria lista azzal a szl kategrival fog kezddni. Ha ezt nem engedlyezed, akkor a szl kategria neve nem fog megjelenni.');
@define('WARNING_NO_GROUPS_SELECTED', 'Figyelem: nem jelltl ki egyetlen csoporttagsgot sem. gy nem tudod majd a csoport jogokat szerkeszteni, ezrt az eredeti csoporttagsgaid nem vltoztak.');
@define('INSTALL_RSSFETCHLIMIT', 'A hrcsatornban megjelentend bejegyzsek');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Az RSS hrcsatornban megjelentend bejegyzsek szma.');
@define('INSTAL_DB_UTF8', 'Adatbzis katakterkonverzi engedlyezse');
@define('INSTAL_DB_UTF8_DESC', 'MySQL esetben add ki a kvetkez parancsot a szksges karakterkdols megllaptshoz: "SET NAMES". Kapcsold ki vagy be ezt az opcit, ha furcsa karaktereket ltsz a blog-ban.');
@define('ONTHEFLYSYNCH', 'Menet kzbeni mdiafjl-szinkronizci engedlyezse');
@define('ONTHEFLYSYNCH_DESC', 'Ha ezt engedlyezed, a Serendipity sszehasonltja a mdia adatbzist a szerveren tallhat fjlokkal, s szinkronizlja ket.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'A felhasznli nv nem lehet res.');
@define('FURTHER_LINKS', 'Tovbbi hivatkozsok');
@define('FURTHER_LINKS_S9Y', 'Serendipity weboldal');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Dokumentci');
@define('FURTHER_LINKS_S9Y_BLOG', 'Hivatalos blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Frumok');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Hozzszls trlve)');

@define('CURRENT_AUTHOR', 'Jelenlegi szerz');

@define('WORD_NEW', 'j');
@define('SHOW_MEDIA_TOOLBAR', 'Mutassuk az eszkztrat a mdiavlaszt ablakban?');
@define('MEDIA_KEYWORDS', 'Mdia kulcsszavak');
@define('MEDIA_KEYWORDS_DESC', 'Adj meg ";"-vel elvlasztott szavakat, amelyeket szeretnl hasznlni a mdiaelemeknl elre definilt kulcsszavakknt.');
@define('MEDIA_EXIF', 'EXIF/JPEG kpadatok importlsa');
@define('MEDIA_EXIF_DESC', 'Ha ezt engedlyezed, akkor a kpeknl mr ltez EXIF/JPEG metaadatok bekerlnek az adatbzisba, s megjelennek a mdiagalriban.');
@define('MEDIA_PROP', 'Mdia tulajdonsgok');


@define('GO_ADD_PROPERTIES', 'Mehet, majd utna a tulajdonsgok szerkesztse');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Rvid megjegyzs');
@define('MEDIA_PROPERTY_COMMENT2', 'Hossz megjegyzs');
@define('MEDIA_PROPERTY_TITLE', 'Cm');
@define('MEDIA_PROP_DESC', 'Adj meg ";"-vel elvlasztott tulajdonsgokat, amelyeket szeretnl hasznlni a mdia fjloknl');
@define('MEDIA_PROP_MULTIDESC', '(Brmelyik elem mg hozzfzheted hogy ":MULTI", gy jelezve azt, hogy ez a mez nagyobb szveget is tartalmazhat, nemcsak kisebb szveget)');

@define('STYLE_OPTIONS_NONE', 'Ennek a tmnak/stlusnak nincsenek specilis opcii. A sablon opciihoz olvasd el a dokumentcit a kvetkez oldalon www.s9y.org a "Configuration of Theme options" rsznl.');
@define('STYLE_OPTIONS', 'Tma/stlus opcik');

@define('PLUGIN_AVAILABLE_COUNT', 'sszesen: %d modul.');

@define('SYNDICATION_RFC2616', 'RFC2616 formtum RSS hrcsatorna kompatibilits belltsa');
@define('SYNDICATION_RFC2616_DESC', 'Ha a RFC2616 formtum kompatibilitst NEM engedlyezed, akkor a aki lekri a hrcsatornt, mindig az utols lekrs ta frisslt elemeket kapja vissza, ami alapveten j mkds. Van nhny RSS kliens viszont, mint pldul a Planet, amelyek furcsn viselkednek ilyenkor, ami nem RFC2616 kompatibilis.  gy ha ezt engedlyezed, kompatibilis leszel a szabvnnyal, de nhny olvas lemaradhat bizonyos hrekrl. Itt olvashatsz errl tbbet: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Hozzrndelt dtum');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Az automatikusan ltrehozott j fjlnv: %s');
@define('MEDIA_UPLOAD_SIZE', 'Feltlthet maximlis fjlmret');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Add meg a maximlisan feltlthet fjlmretet. Ezt a szerver oldalon is fell lehet brlni a PHP.ini-ben a kvetkez belltsokkal: upload_max_filesize, post_max_size, max_input_time ; mindegyikk felldefinilja az itt belltott rtket. Az resen hagyott mez azt jelenti, hogy a szerver belltsait hasznljuk.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Hiba: Nem tlthetsz fel nagyobb mret fjlt mint %s bjt!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Feltltend kpek maximlis szlessge');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Megadhatod a feltltend kpek maximlis szlessgt.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Feltltend kpek maximlis magassga');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Megadhatod a feltltend kpek maximlis magassgt.');
@define('MEDIA_UPLOAD_DIMERROR', 'Hiba: Nem tlthetsz fel nagyobb mret kpet mint %s x %s pixel!');

@define('MEDIA_TARGET', 'A hivatkozs clja (target)');
@define('MEDIA_TARGET_JS', 'Felbukkan ablak (JavaScript-el, igaztott mret)');
@define('MEDIA_ENTRY', 'nll bejegyzs');
@define('MEDIA_TARGET_BLANK', 'Felbukkan ablak (target=_blank -el)');

@define('MEDIA_DYN_RESIZE', 'Engedlyezzk a kpek automatikus tmretezst?');
@define('MEDIA_DYN_RESIZE_DESC', 'Ha ezt engedlyezed, a mdiavlaszt megadott mretre konvertlj a hivatkozozz kpeket. Az eredmnyek eltrolsra kerlnek. gy ha ezt srn hasznlod, sok fjlod sszegylhet.');

@define('MEDIA_DIRECTORY_MOVED', 'A knyvtr s a fjlok sikeresen tkerltek ide: %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'A knyvtrt s a fjlokat nem sikerlt tmozgatni ide: %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'Nem MySQL adatbzis esetben nem lehetsges az sszes bejegyzsben szerepl rgi knyvtr URL-t lecserlni az jra. Ezt kzzel kell megtenned. Ha ezt nem szeretnd, visszamozgathatod az eredeti knyvtrat oda ahol volt.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Az j knyvtr URL-jt ennyi bejegyzsben mdostottuk: %s.');
@define('PLUGIN_ACTIVE', 'Aktv');
@define('PLUGIN_INACTIVE', 'Inaktv');
@define('PREFERENCE_USE_JS', 'Halad JavaScript engedlyezse?');
@define('PREFERENCE_USE_JS_DESC', 'Ha ezt engedlyezed, akkor halad JavaScript-et hasznlunk, pldul a modul belltsoknl thelyezheted a modul dobozokat a fogd s vidd mdszerrel.');

@define('PREFERENCE_USE_JS_WARNING', '(Az oldal halad JavaScript-et hasznl. Amennyiben funkcionlis problmid vannak, tiltsd le ezt a szemlyes belltsaidnl, vagy a bngszd JavaScript hasznlatt)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'tvonal a hozzszlsokhoz');
@define('PERM_SET_CHILD', 'Jogosultsg rkltetse az almappkra is');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Letiltott modulok');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Letiltott esemnyek');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Modulokra rvnyes ACL (bvebb jogosultsgkezels) engedlyezse felhasznlcsoportonknt?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Ha ezt engedlyezed, bellthatod hogy mely felhasznli csoportok kezelhetnek modulokat/esemnyeket.');
@define('DELETE_SELECTED_ENTRIES', 'Kijellt bejegyzsek trlse');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Csak a a legalbb X bejegyzssel rendelkez szerzk mutatsa');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Knyvjelz hivatkozs');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Add a knyvjelzkhz ezt a hivatkozst, gy knnyen elred a blog-odat amikor egy msik oldalon vagy, amirl ppen rni szeretnl.');
@define('IMPORT_WP_PAGES', 'Csatolsok s statikus oldalak letltse mint normlis bejegyzsek?');
@define('USERCONF_CREATE', 'Felhasznl letiltsa / aktivits tiltsa?');
@define('USERCONF_CREATE_DESC', 'Ha ezt vlasztod, a felhasznl nem hozhat ltre bejegyzseket s nem szerkeszthet semmit. Bejelentkezse utn, csak kijelentkezni tud, illetve megtekintheti szemlyes belltsait.');
@define('CATEGORY_HIDE_SUB', 'Az alkategrikhoz kldtt zenetek elrejtse?');
@define('CATEGORY_HIDE_SUB_DESC', 'Alaprtelmezsben amikor egy kategrit bngszel, az alkategrikhoz bekldtt hozzszlsok is ltszdnak. Ha ezt engedlyezed, csak az ppen kijellt kategrihoz rkezett hozzszlsok lesznek lthatak.');
@define('PINGBACK_SENDING', 'URL ltezsnek ellenrzse: %s...');
@define('PINGBACK_SENT', 'Az URL ltezs ellenrzse sikeres');
@define('PINGBACK_FAILED', 'Az URL ltezs ellenrzse sikertelen: %s');
@define('PINGBACK_NOT_FOUND', 'Nem tallhat hivatkozs az URL ltezs ellenrzshez.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Az archvum hivatkozs elrejtse, ha nincs abban az idszakban bejegyzs (a bejegyzsek szmolsa szksges)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS importlsa, PHP5 szksges, s lehet hogy sok memrit ignyel');
@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
